=======
History
=======

Commit history
--------------

See commit log on github, https://github.com/equinor/fmu-ensemble/commits/

First open release (GPLv3) in June 2019.

Prior work
----------

The fmu.ensemble Python module development was started in August 2018,
as an Equinor internal code project, building prior internal
work from at leastL:

* Smørbukk Sør webportal
* Post-processing library made for webportal (2017/2018) https://github.com/Statoil/fmu_postprocessing
* PyPostFMU https://git.equinor.com/FDIL/pypostfmu
